Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2713)

Unified Diff: chrome/browser/chromeos/login/screens/device_disabled_screen_view.h

Issue 2700303002: cros: Unify oobe View/Actor naming to just View. (Closed)
Patch Set: Rebase Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/login/screens/device_disabled_screen_view.h
diff --git a/chrome/browser/chromeos/login/screens/device_disabled_screen_actor.h b/chrome/browser/chromeos/login/screens/device_disabled_screen_view.h
similarity index 77%
rename from chrome/browser/chromeos/login/screens/device_disabled_screen_actor.h
rename to chrome/browser/chromeos/login/screens/device_disabled_screen_view.h
index 7fdcc7dd41f0f9681aaa39a773a0b5bd0408ee34..bd063d71ff796f42107085af8fdaa90ba9545df4 100644
--- a/chrome/browser/chromeos/login/screens/device_disabled_screen_actor.h
+++ b/chrome/browser/chromeos/login/screens/device_disabled_screen_view.h
@@ -2,25 +2,24 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_CHROMEOS_LOGIN_SCREENS_DEVICE_DISABLED_SCREEN_ACTOR_H_
-#define CHROME_BROWSER_CHROMEOS_LOGIN_SCREENS_DEVICE_DISABLED_SCREEN_ACTOR_H_
+#ifndef CHROME_BROWSER_CHROMEOS_LOGIN_SCREENS_DEVICE_DISABLED_SCREEN_VIEW_H_
+#define CHROME_BROWSER_CHROMEOS_LOGIN_SCREENS_DEVICE_DISABLED_SCREEN_VIEW_H_
#include <string>
namespace chromeos {
// Interface between the device disabled screen and its representation.
-class DeviceDisabledScreenActor {
+class DeviceDisabledScreenView {
public:
// Allows the representation to access information about the screen.
class Delegate {
public:
- virtual ~Delegate() {
- }
+ virtual ~Delegate() {}
- // Called when the actor is being destroyed. Note that if the Delegate is
+ // Called when the view is being destroyed. Note that if the Delegate is
// destroyed first, it must call SetDelegate(nullptr).
- virtual void OnActorDestroyed(DeviceDisabledScreenActor* actor) = 0;
+ virtual void OnViewDestroyed(DeviceDisabledScreenView* view) = 0;
// Returns the domain that owns the device.
virtual const std::string& GetEnrollmentDomain() const = 0;
@@ -29,8 +28,7 @@ class DeviceDisabledScreenActor {
virtual const std::string& GetMessage() const = 0;
};
- virtual ~DeviceDisabledScreenActor() {
- }
+ virtual ~DeviceDisabledScreenView() {}
virtual void Show() = 0;
virtual void Hide() = 0;
@@ -40,5 +38,4 @@ class DeviceDisabledScreenActor {
} // namespace chromeos
-#endif // CHROME_BROWSER_CHROMEOS_LOGIN_SCREENS_DEVICE_DISABLED_SCREEN_ACTOR_H_
-
+#endif // CHROME_BROWSER_CHROMEOS_LOGIN_SCREENS_DEVICE_DISABLED_SCREEN_VIEW_H_

Powered by Google App Engine
This is Rietveld 408576698